--[[----------------------------------------------------------------------------

Utils.lua
Common utilities to help with Lightroom SDK debugging

--------------------------------------------------------------------------------

Copyright 2018 Grand Avocado Ltd.
All Rights Reserved.

------------------------------------------------------------------------------]]

local logger = import 'LrLogger'( 'Muyphoto' )
logger:enable("logfile")

Utils = {}

function Utils.logInfo(...)
	--[[
	printResult = "[INFO]\t"
	for i,v in ipairs(arg) do
		printResult = printResult .. tostring(v) .. "\t"
	end
	logger:trace(printResult)
	]]
end

function Utils.logError(...)
	--[[
	printResult = "[ERROR]\t"
	for i,v in ipairs(arg) do
		printResult = printResult .. tostring(v) .. "\t"
	end
	logger:error(printResult)
	]]
end

function Utils.makeQueryString(params)
	qstring = ""
	for key, value in pairs(params) do
		if qstring ~= "" then
			qstring = qstring .. "&"
		end
		qstring = qstring .. key .. "=" .. tostring(value)
	end
	return qstring
end

-- variation of http://forums.adobe.com/message/3146133#3146133
function Utils.logTable(x, label)
	local function dump1 (x, indent, visited)
		if type (x) ~= "table" then
			logger:info (string.rep (" ", indent) .. tostring (x))
			return
		end

		visited [x] = true
		if indent == 0 then
			logger:info (string.rep (" ", indent) .. tostring (x))
		end
		for k, v in pairs (x) do
			logger:info (string.rep (" ", indent + 4) .. tostring (k) .. " = " ..
					tostring (v))
			if type (v) == "table" and not visited [v] then
				dump1 (v, indent + 4, visited)
			end
		end
	end

	if label ~= nil then
		logger:info (label .. ":")
	end

	dump1 (x, 0, {})
end

--[[
Utils.monthNames = {
	LOC "$$$/Kuvatilaus/MonthName01=Tammikuu",
	LOC "$$$/Kuvatilaus/MonthName02=Helmikuu",
	LOC "$$$/Kuvatilaus/MonthName03=Maaliskuu",
	LOC "$$$/Kuvatilaus/MonthName04=Huhtikuu",
	LOC "$$$/Kuvatilaus/MonthName05=Toukokuu",
	LOC "$$$/Kuvatilaus/MonthName06=Kesäkuu",
	LOC "$$$/Kuvatilaus/MonthName07=Heinäkuu",
	LOC "$$$/Kuvatilaus/MonthName08=Elokuu",
	LOC "$$$/Kuvatilaus/MonthName09=Syyskuu",
	LOC "$$$/Kuvatilaus/MonthName10=Lokakuu",
	LOC "$$$/Kuvatilaus/MonthName11=Marraskuu",
	LOC "$$$/Kuvatilaus/MonthName12=Joulukuu",
}
]]

Utils.monthNames = {
	LOC "$$$/Export/Strings/January=January",
	LOC "$$$/Export/Strings/February=February",
	LOC "$$$/Export/Strings/March=March",
	LOC "$$$/Export/Strings/April=April",
	LOC "$$$/Export/Strings/May=May",
	LOC "$$$/Export/Strings/June=June",
	LOC "$$$/Export/Strings/July=July",
	LOC "$$$/Export/Strings/August=August",
	LOC "$$$/Export/Strings/September=September",
	LOC "$$$/Export/Strings/October=October",
	LOC "$$$/Export/Strings/November=November",
	LOC "$$$/Export/Strings/December=December",
}
